===============
Command Handler
===============

Overview
========

A framework for registering command actions and then invoking them
by passing in a text string, which could either be from the script
comand line or some other source - say a slack api call.



